CrImpl class
- Available extensions
Constructors
- CrImpl()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addLocMixerOutput(
String mixerID, String mixerOutPutCfgs) → Future< int> -
Available on CrImpl, provided by the CrRecordImpl extension
-
closeMic(
String userID) → Future< void> -
Available on CrImpl, provided by the CrAudioImpl extension
-
closeVideo(
String userID) → Future< void> -
Available on CrImpl, provided by the CrVideoImpl extension
-
cloudroomVideoSDKVer(
) → Future< String> -
createLocMixer(
String mixerID, String mixerCfg, String mixerCotentRects) → Future< int> -
Available on CrImpl, provided by the CrRecordImpl extension
-
createMediaView(
int viewID, String usrVideoId) → Future< void> -
Available on CrImpl, provided by the CrMediaImpl extension
-
createMeeting(
) → Future< Map> -
Available on CrImpl, provided by the CrRoomImpl extension
-
destroyLocMixer(
String mixerID) → Future< void> -
Available on CrImpl, provided by the CrRecordImpl extension
-
destroyMediaView(
int viewID) → Future< bool> -
Available on CrImpl, provided by the CrMediaImpl extension
-
destroyMeeting(
int meetID) → Future< Map> -
Available on CrImpl, provided by the CrRoomImpl extension
-
destroyPlatformView(
int viewID) → Future< bool> -
Available on CrImpl, provided by the CrVideoImpl extension
-
Available on CrImpl, provided by the CrScreenShareImpl extension
-
enterMeeting(
int meetID) → Future< int> -
Available on CrImpl, provided by the CrRoomImpl extension
-
exitMeeting(
) → Future< void> -
Available on CrImpl, provided by the CrRoomImpl extension
-
getAllCloudMixerInfo(
) → Future< String> -
Available on CrImpl, provided by the CrRecordImpl extension
-
getAllMembers(
) → Future< String> -
Available on CrImpl, provided by the CrMemberImpl extension
-
getAllVideoInfo(
String userID) → Future< String> -
Available on CrImpl, provided by the CrVideoImpl extension
-
getAudioCfg(
) → Future< String> -
Available on CrImpl, provided by the CrAudioImpl extension
-
getAudioStatus(
String userID) → Future< int> -
Available on CrImpl, provided by the CrAudioImpl extension
-
getDefaultVideo(
String userID) → Future< int> -
Available on CrImpl, provided by the CrVideoImpl extension
-
getLocMixerState(
String mixerID) → Future< int> -
Available on CrImpl, provided by the CrRecordImpl extension
-
getMediaCfg(
) → Future< String> -
Available on CrImpl, provided by the CrMediaImpl extension
-
getMediaInfo(
) → Future< String> -
Available on CrImpl, provided by the CrMediaImpl extension
-
getMediaVolume(
) → Future< int> -
Available on CrImpl, provided by the CrMediaImpl extension
-
getMemberInfo(
String userID) → Future< String> -
Available on CrImpl, provided by the CrMemberImpl extension
-
getMicVolume(
) → Future< int> -
Available on CrImpl, provided by the CrAudioImpl extension
-
getMyUserID(
) → Future< String> -
Available on CrImpl, provided by the CrMemberImpl extension
-
getNickName(
String userID) → Future< String> -
Available on CrImpl, provided by the CrMemberImpl extension
-
getScaleType(
int viewID) → Future< int> -
Available on CrImpl, provided by the CrVideoImpl extension
-
Available on CrImpl, provided by the CrScreenShareImpl extension
-
getServerAddr(
) → Future< String> -
getSpeakerOut(
) → Future< bool> -
Available on CrImpl, provided by the CrAudioImpl extension
-
getSpeakerVolume(
) → Future< int> -
Available on CrImpl, provided by the CrAudioImpl extension
-
getSvrMixerState(
) → Future< int> -
Available on CrImpl, provided by the CrRecordImpl extension
-
getVideoCfg(
) → Future< String> -
Available on CrImpl, provided by the CrVideoImpl extension
-
getWatchableVideos(
) → Future< String> -
Available on CrImpl, provided by the CrVideoImpl extension
-
init(
String sdkInitDat) → Future< int> -
Available on CrImpl, provided by the CrScreenShareImpl extension
-
isUserInMeeting(
String userID) → Future< bool> -
Available on CrImpl, provided by the CrMemberImpl extension
-
log(
String log, int level) → Future< void> -
login(
String loginDat) → Future< Map> -
Available on CrImpl, provided by the CrAuthImpl extension
-
logout(
) → Future< void> -
Available on CrImpl, provided by the CrAuthImpl extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openMic(
String userID) → Future< void> -
Available on CrImpl, provided by the CrAudioImpl extension
-
openVideo(
String userID) → Future< Map> -
Available on CrImpl, provided by the CrVideoImpl extension
-
pausePlayMedia(
bool pause) → Future< void> -
Available on CrImpl, provided by the CrMediaImpl extension
-
rmLocMixerOutput(
String mixerID, String nameOrUrls) → Future< void> -
Available on CrImpl, provided by the CrRecordImpl extension
-
sendMeetingCustomMsg(
String text) → Future< Map> -
Available on CrImpl, provided by the CrChatImpl extension
-
setAudioCfg(
String audioCfg) → Future< void> -
Available on CrImpl, provided by the CrAudioImpl extension
-
setDefaultVideo(
String userID, int videoID) → Future< void> -
Available on CrImpl, provided by the CrVideoImpl extension
-
setMediaCfg(
String cfg) → Future< void> -
Available on CrImpl, provided by the CrMediaImpl extension
-
setMediaPlayPos(
int pos) → Future< void> -
Available on CrImpl, provided by the CrMediaImpl extension
-
setMediaVolume(
int volume) → Future< void> -
Available on CrImpl, provided by the CrMediaImpl extension
-
setNickName(
String userID, String nickName) → Future< Map> -
Available on CrImpl, provided by the CrMemberImpl extension
-
setScaleType(
int viewID, int scaleType) → Future< void> -
Available on CrImpl, provided by the CrVideoImpl extension
-
Available on CrImpl, provided by the CrScreenShareImpl extension
-
setServerAddr(
String serverAddr) → Future< void> -
setSpeakerOut(
bool speakerOut) → Future< bool> -
Available on CrImpl, provided by the CrAudioImpl extension
-
setSpeakerVolume(
int speakerVolume) → Future< bool> -
Available on CrImpl, provided by the CrAudioImpl extension
-
setUsrVideoId(
int viewID, String usrVideoId) → Future< void> -
Available on CrImpl, provided by the CrVideoImpl extension
-
setVideoCfg(
String cfg) → Future< void> -
Available on CrImpl, provided by the CrVideoImpl extension
-
startPlayMedia(
String videoSrc, bool bLocPlay) → Future< void> -
Available on CrImpl, provided by the CrMediaImpl extension
-
Available on CrImpl, provided by the CrScreenShareImpl extension
-
Available on CrImpl, provided by the CrScreenShareImpl extension
-
startSvrMixer(
String mutiMixerCfg, String mutiMixerContents, String mutiMixerOutput) → Future< int> -
Available on CrImpl, provided by the CrRecordImpl extension
-
stopPlayMedia(
) → Future< void> -
Available on CrImpl, provided by the CrMediaImpl extension
-
Available on CrImpl, provided by the CrScreenShareImpl extension
-
stopSvrMixer(
) → Future< void> -
Available on CrImpl, provided by the CrRecordImpl extension
-
toString(
) → String -
A string representation of this object.
inherited
-
uninit(
) → Future< void> -
updateLocMixerContent(
String mixerID, String mixerCotentRects) → Future< int> -
Available on CrImpl, provided by the CrRecordImpl extension
-
updateSvrMixerContent(
String mutiMixerContents) → Future< int> -
Available on CrImpl, provided by the CrRecordImpl extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited